import httpx
import json
import os

class AI:
    def __init__(self):
        self.api_key = os.getenv("CLA_KEY")
        base_url = os.getenv("CLA_BASE_URL").rstrip("/")
        self.ai_model = os.getenv("CLA_MODEL")
        self.api_url = base_url + "/chat/completions"

    async def send_message(self, message, so):
        """
        Envia uma mensagem para o modelo e imprime a resposta em tempo real.
        
        :param message: Mensagem a ser enviada para o modelo.
        :param so: Sistema operacional (Linux, Windows, Mac).
        """
        headers = {
            "Authorization": f"Bearer {self.api_key}",
            "Content-Type": "application/json"
        }
        
        data = {
            "model": self.ai_model,
            "messages": [
                {"role": "system", "content": f"Você é um assistente de linha de comando."},
                {"role": "system", "content": f"Você deve responder apenas com comandos para terminal."},
                {"role": "system", "content": f"Não deve responder com explicações, aspas ou formatações."},
                {"role": "system", "content": f"Sistema: {so} | Diretório atual: {os.getcwd()}"},
                {"role": "user", "content": f"{message}"}
            ],
            "stream": True,
            "max_tokens": 150
        }

        final_response = []
        print('\n', end="")
        print("***************************[CL-Assistant]***************************")
        async with httpx.AsyncClient(timeout=None) as client:
            async with client.stream("POST", self.api_url, headers=headers, json=data) as response:

                if response.status_code != 200:
                    print(f"Erro na API: {response}")
                    return
                async for line in response.aiter_lines():
                    if line.strip().startswith("data: "):
                        content = line.removeprefix("data: ").strip()
                        try:
                            content = json.loads(content)['choices'][0]['delta']['content']
                        except:
                            content = ""

                        final_response.append(content)
                        print(content, end="", flush=True)        
        print('\n', end="")
        print("********************************************************************")
        key = input("Deseja executar o comando? [S/n]")
        if key.lower() == 's':
            os.system("".join(final_response))


from importlib.metadata import version
import argparse
import asyncio
from cla.chat import AI
import platform
import os

__version__ = version("cl-assistant")

async def main(command:str, so:str):
    """
    Função principal que inicializa a classe AI e envia a mensagem.
    :param command: Comando a ser enviado para o modelo.
    :param so: Sistema operacional (Linux, Windows, Mac). Automaticamente detectado se não for fornecido.
    """
    
    missing = []

    if "CLA_KEY" not in os.environ:
        missing.append("A chave da API 'CLA_KEY' nao esta definida no ambiente. Pode ser uma chave da OpenAI ou DeepSeek.")

    if "CLA_BASE_URL" not in os.environ:
        missing.append("A URL base 'CLA_BASE_URL' nao esta definida no ambiente. Pode ser a Base URL da OpenAI ou DeepSeek.")

    if "CLA_MODEL" not in os.environ:
        missing.append("O modelo 'CLA_MODEL' nao esta definido no ambiente. Pode ser o modelo da OpenAI ou DeepSeek. Ex: 'deepseek-chat'.")

    if missing:
        for message in missing:
            print(f"{message}")
        exit(1)
    
    ai = AI()

    await ai.send_message(command, so)


def cli():
    parser = argparse.ArgumentParser(description="Command Line Assistant (CLA)")

    parser.add_argument("comando", nargs="+", help="Comando em linguagem natural para o CLA")
    parser.add_argument("--so", help="Sistema operacional (Linux, Windows, Mac)", default=platform.system())
    parser.add_argument("--version", action="version", version=f"CL-Assistant - versão {__version__}")

    args = parser.parse_args()
    
    comando = " ".join(args.comando)
    
    asyncio.run(main(comando, args.so))
